<!-- AUTO-GENERATED FILE - DO NOT EDIT DIRECTLY -->
<!-- Edit source frontmatter, then run 'erk docs sync' to regenerate. -->

# Objectives Documentation

- **[objective-roadmap-check.md](objective-roadmap-check.md)** — working with objective roadmap markdown tables, parsing or validating objective structure, implementing objective progress tracking, debugging roadmap parsing issues
- **[research-documentation-integration.md](research-documentation-integration.md)** — creating research documentation during objective work, linking learned docs to objective issues, working with objective research phases, documenting discoveries from objective investigations
- **[roadmap-mutation-patterns.md](roadmap-mutation-patterns.md)** — deciding between surgical vs full-body roadmap updates, implementing roadmap mutation logic, understanding when to use update-roadmap-step vs objective-update-with-landed-pr
- **[roadmap-parser-api.md](roadmap-parser-api.md)** — calling parse_roadmap(), compute_summary(), serialize_phases(), or find_next_step(), working with RoadmapStep or RoadmapPhase dataclasses, building new features on top of the roadmap parser
- **[roadmap-parser.md](roadmap-parser.md)** — understanding how roadmap steps are parsed, working with objective roadmap check or update commands, debugging roadmap parsing issues, using erk exec objective-roadmap-check or objective-roadmap-update
- **[roadmap-status-system.md](roadmap-status-system.md)** — understanding how objective roadmap status is determined, working with roadmap step status values, implementing objective roadmap parsing logic
- **[roadmap-validation.md](roadmap-validation.md)** — debugging roadmap validation errors, understanding what the roadmap parser validates, adding new validation rules to the roadmap parser
